v0.2.2 (2023-12-12)
-------------------
- Support Python 3.10, 3.11, and 3.12
- Drop support for Python 3.6
- Migrated from setuptools to hatch
- Declare the project unsupported going forwards

v0.2.1 (2021-05-31)
-------------------
- Drop support for Python 3.4 and 3.5
- Support Python 3.9
- Support Click 8

v0.2.0 (2020-01-24)
-------------------
- `--font` now accepts names of builtin fonts
- When an input filename is given but no output filename, write to the input
  filename with the extension set to `.pdf` instead of to stdout
- Eliminated the `--multiline` option and made its behavior the default
- Added a `--sort` option and made `--no-sort` the default behavior
- Support Python 3.8

v0.1.0 (2019-04-15)
-------------------
Initial release
